import Catalog from './catalog/catalog';
import Translator from './translator/translator';
import ToolbarButton from './components/toolbar/toolbar-button';
import Ruler from './components/viewer2d/ruler';
import * as Models from './models'
import State2DViewer from './components/viewer2d/state';
import reducer from './reducers/reducer';
import ReactPlanner from './react-planner';
import Plugins from './plugins/plugins';
import WallFactory from './catalog/factories/wall-factory.jsx';
import AreaFactory from './catalog/factories/area-factory.jsx';

let ElementsFactories = {WallFactory, AreaFactory};

console.info(`react-planner started`); //MIT LICENSE COMPLIANT

export {
  Catalog, Translator, ToolbarButton, Ruler, Models, State2DViewer, reducer, ReactPlanner, Plugins, ElementsFactories
};
